@@ -141,7 +141,7 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 
 #define BACKLOG (100)
 
-#define AUTH_REALM "gSOAP Web Server Admin"
+#define AUTH_REALM "gSOAP Web Server Admin demo login: admin guest"
 #define AUTH_USERID "admin"	/* user ID to access admin pages */
 #define AUTH_PASSWD "guest"	/* user pw to access admin pages */
 
@@ -1287,13 +1287,16 @@ int html_hist(struct soap *soap, const char *title, size_t barwidth, size_t heig
 #ifdef WITH_OPENSSL
 
 struct CRYPTO_dynlock_value
-{ MUTEX_TYPE mutex;
+{
+  MUTEX_TYPE mutex;
 };
 
 static MUTEX_TYPE *mutex_buf;
 
 static struct CRYPTO_dynlock_value *dyn_create_function(const char *file, int line)
-{ struct CRYPTO_dynlock_value *value;
+{
+  struct CRYPTO_dynlock_value *value;
+  (void)file; (void)line;
   value = (struct CRYPTO_dynlock_value*)malloc(sizeof(struct CRYPTO_dynlock_value));
   if (value)
     MUTEX_SETUP(value->mutex);
@@ -1301,31 +1304,39 @@ static struct CRYPTO_dynlock_value *dyn_create_function(const char *file, int li
 }
 
 static void dyn_lock_function(int mode, struct CRYPTO_dynlock_value *l, const char *file, int line)
-{ if (mode & CRYPTO_LOCK)
+{
+  (void)file; (void)line;
+  if (mode & CRYPTO_LOCK)
     MUTEX_LOCK(l->mutex);
   else
     MUTEX_UNLOCK(l->mutex);
 }
 
 static void dyn_destroy_function(struct CRYPTO_dynlock_value *l, const char *file, int line)
-{ MUTEX_CLEANUP(l->mutex);
+{
+  (void)file; (void)line;
+  MUTEX_CLEANUP(l->mutex);
   free(l);
 }
 
-void locking_function(int mode, int n, const char *file, int line)
-{ if (mode & CRYPTO_LOCK)
+static void locking_function(int mode, int n, const char *file, int line)
+{
+  (void)file; (void)line;
+  if (mode & CRYPTO_LOCK)
     MUTEX_LOCK(mutex_buf[n]);
   else
     MUTEX_UNLOCK(mutex_buf[n]);
 }
 
-unsigned long id_function()
-{ return (unsigned long)THREAD_ID;
+static unsigned long id_function()
+{
+  return (unsigned long)THREAD_ID;
 }
 
 int CRYPTO_thread_setup()
-{ int i;
-  mutex_buf = (MUTEX_TYPE*)malloc(CRYPTO_num_locks() * sizeof(MUTEX_TYPE));
+{
+  int i;
+  mutex_buf = (MUTEX_TYPE*)malloc(CRYPTO_num_locks() * sizeof(pthread_mutex_t));
   if (!mutex_buf)
     return SOAP_EOM;
   for (i = 0; i < CRYPTO_num_locks(); i++)
@@ -1339,7 +1350,8 @@ int CRYPTO_thread_setup()
 }
 
 void CRYPTO_thread_cleanup()
-{ int i;
+{
+  int i;
   if (!mutex_buf)
     return;
   CRYPTO_set_id_callback(NULL);
