@@ -69,6 +69,7 @@ int _flag = 0,
     jflag = 0,
     kflag = 0,
     mflag = 0,
+    Mflag = 0,
     pflag = 0,
     Pflag = 0,
     Rflag = 0,
@@ -298,6 +299,9 @@ static void options(int argc, char **argv)
 	  case 'm':
 	    mflag = 1;
 	    break;
+	  case 'M':
+	    Mflag = 1;
+	    break;
           case 'n':
             a++;
             g = 0;
@@ -444,7 +448,7 @@ static void options(int argc, char **argv)
 	    break;
           case '?':
           case 'h':
-            fprintf(stderr, "Usage: wsdl2h [-a] [-b] [-c|-c++|-c++11] [-d] [-e] [-f] [-g] [-h] [-I path] [-i] [-j] [-k] [-l] [-m] [-N name] [-n name] [-P|-p] [-q name] [-R] [-r proxyhost[:port[:uid:pwd]]] [-r:userid:passwd] [-s] [-t typemapfile] [-U] [-u] [-v] [-w] [-W] [-x] [-y] [-z#] [-_] [-o outfile.h] infile.wsdl infile.xsd http://www... ...\n\n");
+            fprintf(stderr, "Usage: wsdl2h [-a] [-b] [-c|-c++|-c++11] [-d] [-e] [-f] [-g] [-h] [-I path] [-i] [-j] [-k] [-l] [-m] [-M] [-N name] [-n name] [-P|-p] [-q name] [-R] [-r proxyhost[:port[:uid:pwd]]] [-r:userid:passwd] [-s] [-t typemapfile] [-U] [-u] [-v] [-w] [-W] [-x] [-y] [-z#] [-_] [-o outfile.h] infile.wsdl infile.xsd http://www... ...\n\n");
             fprintf(stderr, "\
 -a      generate indexed struct names for local elements with anonymous types\n\
 -b	bi-directional operations (duplex ops) added to serve one-way responses\n\
@@ -462,6 +466,7 @@ static void options(int argc, char **argv)
 -k      don't generate SOAP_ENV__Header mustUnderstand qualifiers\n\
 -l      display license information\n\
 -m      use xsd.h module to import primitive types\n\
+-M      suppress error \"must understand element with wsdl:required='true'\"\n\
 -Nname  use name for service prefixes to produce a service for each binding\n\
 -nname  use name as the base namespace prefix instead of 'ns'\n\
 -ofile  output to file\n\
@@ -573,7 +578,8 @@ struct Namespace namespaces[] =
   {"gwsdl", "http://www.gridforum.org/namespaces/2003/03/gridWSDLExtensions"},
   {"wsa_", "http://www.w3.org/2005/08/addressing"},
   {"wsam", "http://www.w3.org/2007/05/addressing/metadata"},
-  {"wsrmp", "http://schemas.xmlsoap.org/ws/2005/02/rm/policy", "http://docs.oasis-open.org/ws-rx/wsrmp/*"},
+  {"wsrmp", "http://docs.oasis-open.org/ws-rx/wsrm/200702", "http://docs.oasis-open.org/ws-rx/wsrm/*"},
+  {"wsrmp5", "http://schemas.xmlsoap.org/ws/2005/02/rm/policy"},
   {"sp", "http://docs.oasis-open.org/ws-sx/ws-securitypolicy/200702", "http://schemas.xmlsoap.org/ws/2005/07/securitypolicy"},
   {"wsp_", "http://www.w3.org/ns/ws-policy", "http://schemas.xmlsoap.org/ws/2004/09/policy"},
   {"wst_", "http://docs.oasis-open.org/ws-sx/ws-trust/200512"},
